@@ -1,16 +1,16 @@
 import logging
+from contextlib import suppress
 from weakref import WeakKeyDictionary
 
+import scrapy
 from scrapy import signals
 from scrapy.exceptions import ScrapyDeprecationWarning
 from scrapy.exporters import PythonItemExporter
 from scrapy.http import Request
-from scrapy.item import BaseItem
 from scrapy.utils.deprecate import create_deprecated_class
 from scrapy.utils.request import request_fingerprint
 
 from sh_scrapy import hsref
-from sh_scrapy.compat import IS_PYTHON2
 from sh_scrapy.crawl import ignore_warnings
 from sh_scrapy.exceptions import SHScrapyDeprecationWarning
 from sh_scrapy.middlewares import HS_PARENT_ID_KEY, request_id_sequence
@@ -18,10 +18,18 @@ from sh_scrapy.writer import pipe_writer
 
 
 try:
-    from itemadapter import is_item
+    from itemadapter import ItemAdapter
 except ImportError:
+    _base_item_cls = [dict, scrapy.item.Item]
+    with suppress(AttributeError):
+        _base_item_cls.append(scrapy.item.BaseItem)
+    _base_item_cls = tuple(_base_item_cls)
+
     def is_item(item):
-        return isinstance(item, (dict, BaseItem))
+        return isinstance(item, _base_item_cls)
+else:
+    def is_item(item):
+        return ItemAdapter.is_item(item)
 
 
 class HubstorageExtension(object):
@@ -34,7 +42,7 @@ class HubstorageExtension(object):
         self.logger = logging.getLogger(__name__)
         self._write_item = self.pipe_writer.write_item
         # https://github.com/scrapy/scrapy/commit/c76190d491fca9f35b6758bdc06c34d77f5d9be9
-        exporter_kwargs = {'binary': False} if not IS_PYTHON2 else {}
+        exporter_kwargs = {'binary': False}
         with ignore_warnings(category=ScrapyDeprecationWarning):
             self.exporter = PythonItemExporter(**exporter_kwargs)
 
