@@ -5,15 +5,16 @@ import shutil
 import tempfile
 
 import pytest
+from scrapy.utils.python import to_unicode, to_bytes
 
 TEMP_DIR = tempfile.mkdtemp()
 SHUB_FIFO_PATH = os.path.join(TEMP_DIR, 'scrapinghub')
 os.environ['SHUB_FIFO_PATH'] = SHUB_FIFO_PATH
 
-from sh_scrapy.writer import pipe_writer
-from sh_scrapy.compat import to_native_str, to_bytes
+from sh_scrapy.writer import pipe_writer  # should go after setting SHUB_FIFO_PATH
 
-TEST_AUTH = to_native_str(codecs.encode(to_bytes('1/2/3:authstr'), 'hex_codec'))
+
+TEST_AUTH = to_unicode(codecs.encode(to_bytes('1/2/3:authstr'), 'hex_codec'))
 
 
 @pytest.fixture(scope='session', autouse=True)
